@@ -1,4 +1,5 @@
-/* vim: set sw=4 sts=4: -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* vim: set sw=4 sts=4 ts=4 expandtab: */
 /*
    rsvg-shapes.c: Draw shapes with cairo
 
@@ -44,27 +45,27 @@
 static void
 _rsvg_cairo_set_shape_antialias (cairo_t * cr, ShapeRenderingProperty aa)
 {
-	if (SHAPE_RENDERING_AUTO == aa)
-		cairo_set_antialias (cr, CAIRO_ANTIALIAS_DEFAULT);
-	else if (SHAPE_RENDERING_OPTIMIZE_SPEED == aa)
-		cairo_set_antialias (cr, CAIRO_ANTIALIAS_NONE);
-	else if (SHAPE_RENDERING_CRISP_EDGES == aa)
-		cairo_set_antialias (cr, CAIRO_ANTIALIAS_DEFAULT);
-	else if (SHAPE_RENDERING_GEOMETRIC_PRECISION == aa)
-		cairo_set_antialias (cr, CAIRO_ANTIALIAS_DEFAULT);
+    if (SHAPE_RENDERING_AUTO == aa)
+        cairo_set_antialias (cr, CAIRO_ANTIALIAS_DEFAULT);
+    else if (SHAPE_RENDERING_OPTIMIZE_SPEED == aa)
+        cairo_set_antialias (cr, CAIRO_ANTIALIAS_NONE);
+    else if (SHAPE_RENDERING_CRISP_EDGES == aa)
+        cairo_set_antialias (cr, CAIRO_ANTIALIAS_NONE);
+    else if (SHAPE_RENDERING_GEOMETRIC_PRECISION == aa)
+        cairo_set_antialias (cr, CAIRO_ANTIALIAS_DEFAULT);
 }
 
 static void
 _rsvg_cairo_set_text_antialias (cairo_t * cr, TextRenderingProperty aa)
 {
-	if (TEXT_RENDERING_AUTO == aa)
-		cairo_set_antialias (cr, CAIRO_ANTIALIAS_DEFAULT);
-	else if (TEXT_RENDERING_OPTIMIZE_SPEED == aa)
-		cairo_set_antialias (cr, CAIRO_ANTIALIAS_NONE);
-	else if (TEXT_RENDERING_OPTIMIZE_LEGIBILITY == aa)
-		cairo_set_antialias (cr, CAIRO_ANTIALIAS_DEFAULT);
-	else if (TEXT_RENDERING_GEOMETRIC_PRECISION == aa)
-		cairo_set_antialias (cr, CAIRO_ANTIALIAS_DEFAULT);
+    if (TEXT_RENDERING_AUTO == aa)
+        cairo_set_antialias (cr, CAIRO_ANTIALIAS_DEFAULT);
+    else if (TEXT_RENDERING_OPTIMIZE_SPEED == aa)
+        cairo_set_antialias (cr, CAIRO_ANTIALIAS_NONE);
+    else if (TEXT_RENDERING_OPTIMIZE_LEGIBILITY == aa)
+        cairo_set_antialias (cr, CAIRO_ANTIALIAS_DEFAULT);
+    else if (TEXT_RENDERING_GEOMETRIC_PRECISION == aa)
+        cairo_set_antialias (cr, CAIRO_ANTIALIAS_DEFAULT);
 }
 
 static void
@@ -107,8 +108,8 @@ _rsvg_cairo_set_operator (cairo_t * cr, RsvgCompOpType comp_op)
         op = CAIRO_OPERATOR_XOR;
         break;
     case RSVG_COMP_OP_PLUS:
-	op = CAIRO_OPERATOR_ADD;
-	break;
+        op = CAIRO_OPERATOR_ADD;
+        break;
     case RSVG_COMP_OP_MULTIPLY:
     case RSVG_COMP_OP_SCREEN:
     case RSVG_COMP_OP_OVERLAY:
@@ -319,7 +320,7 @@ _set_source_rsvg_pattern (RsvgDrawingCtx * ctx,
         bbhscale = 1.0;
     }
 
-    _rsvg_affine_multiply (taffine, rsvg_pattern->affine, rsvg_state_current (ctx)->affine);
+    _rsvg_affine_multiply (taffine, rsvg_pattern->affine, rsvg_current_state (ctx)->affine);
 
     scwscale = sqrt (taffine[0] * taffine[0] + taffine[2] * taffine[2]);
     schscale = sqrt (taffine[1] * taffine[1] + taffine[3] * taffine[3]);
@@ -387,8 +388,8 @@ _set_source_rsvg_pattern (RsvgDrawingCtx * ctx,
     /* Set up transformations to be determined by the contents units */
     rsvg_state_push (ctx);
     for (i = 0; i < 6; i++)
-        rsvg_state_current (ctx)->personal_affine[i] =
-            rsvg_state_current (ctx)->affine[i] = caffine[i];
+        rsvg_current_state (ctx)->personal_affine[i] =
+            rsvg_current_state (ctx)->affine[i] = caffine[i];
 
     /* Draw everything */
     _rsvg_node_draw_children ((RsvgNode *) rsvg_pattern, ctx, 2);
@@ -473,7 +474,7 @@ void
 rsvg_cairo_render_pango_layout (RsvgDrawingCtx * ctx, PangoLayout * layout, double x, double y)
 {
     RsvgCairoRender *render = (RsvgCairoRender *) ctx->render;
-    RsvgState *state = rsvg_state_current (ctx);
+    RsvgState *state = rsvg_current_state (ctx);
     PangoRectangle ink;
     RsvgBbox bbox;
 
@@ -491,13 +492,13 @@ rsvg_cairo_render_pango_layout (RsvgDrawingCtx * ctx, PangoLayout * layout, doub
     bbox.virgin = 0;
 
     if (state->fill) {
-    cairo_move_to (render->cr, x, y);
-    rsvg_bbox_insert (&render->bbox, &bbox);
+        cairo_move_to (render->cr, x, y);
+        rsvg_bbox_insert (&render->bbox, &bbox);
         _set_source_rsvg_paint_server (ctx,
                                        state->current_color,
                                        state->fill,
                                        state->fill_opacity,
-                                       bbox, rsvg_state_current (ctx)->current_color);
+                                       bbox, rsvg_current_state (ctx)->current_color);
 
         pango_cairo_show_layout (render->cr, layout);
     }
@@ -511,9 +512,9 @@ rsvg_cairo_render_pango_layout (RsvgDrawingCtx * ctx, PangoLayout * layout, doub
                                        state->current_color,
                                        state->stroke,
                                        state->stroke_opacity,
-                                       bbox, rsvg_state_current (ctx)->current_color);
+                                       bbox, rsvg_current_state (ctx)->current_color);
 
-	cairo_set_line_width (render->cr, _rsvg_css_normalize_length (&state->stroke_width, ctx, 'h'));
+        cairo_set_line_width (render->cr, _rsvg_css_normalize_length (&state->stroke_width, ctx, 'h'));
         cairo_stroke (render->cr);
     }
 }
@@ -522,7 +523,7 @@ void
 rsvg_cairo_render_path (RsvgDrawingCtx * ctx, const RsvgBpathDef * bpath_def)
 {
     RsvgCairoRender *render = (RsvgCairoRender *) ctx->render;
-    RsvgState *state = rsvg_state_current (ctx);
+    RsvgState *state = rsvg_current_state (ctx);
     cairo_t *cr;
     RsvgBpath *bpath;
     int i;
@@ -611,7 +612,7 @@ rsvg_cairo_render_path (RsvgDrawingCtx * ctx, const RsvgBpathDef * bpath_def)
         _set_source_rsvg_paint_server (ctx,
                                        state->current_color,
                                        state->fill,
-                                       opacity, bbox, rsvg_state_current (ctx)->current_color);
+                                       opacity, bbox, rsvg_current_state (ctx)->current_color);
 
         if (state->stroke != NULL)
             cairo_fill_preserve (cr);
@@ -629,7 +630,7 @@ rsvg_cairo_render_path (RsvgDrawingCtx * ctx, const RsvgBpathDef * bpath_def)
         _set_source_rsvg_paint_server (ctx,
                                        state->current_color,
                                        state->stroke,
-                                       opacity, bbox, rsvg_state_current (ctx)->current_color);
+                                       opacity, bbox, rsvg_current_state (ctx)->current_color);
 
         cairo_stroke (cr);
     }
@@ -643,7 +644,7 @@ rsvg_cairo_render_image (RsvgDrawingCtx * ctx, const GdkPixbuf * pixbuf,
                          double pixbuf_x, double pixbuf_y, double w, double h)
 {
     RsvgCairoRender *render = (RsvgCairoRender *) ctx->render;
-    RsvgState *state = rsvg_state_current (ctx);
+    RsvgState *state = rsvg_current_state (ctx);
 
     gint width = gdk_pixbuf_get_width (pixbuf);
     gint height = gdk_pixbuf_get_height (pixbuf);
@@ -741,19 +742,19 @@ rsvg_cairo_render_image (RsvgDrawingCtx * ctx, const GdkPixbuf * pixbuf,
 #if 1
     cairo_set_source_surface (render->cr, surface, pixbuf_x, pixbuf_y);
 #else
-	{
-		cairo_pattern_t *pattern;
-		cairo_matrix_t matrix;
+    {
+        cairo_pattern_t *pattern;
+        cairo_matrix_t matrix;
 
-		pattern = cairo_pattern_create_for_surface (surface);
-		cairo_pattern_set_extend (pattern, CAIRO_EXTEND_PAD);
+        pattern = cairo_pattern_create_for_surface (surface);
+        cairo_pattern_set_extend (pattern, CAIRO_EXTEND_PAD);
 
-		cairo_matrix_init_translate (&matrix, -pixbuf_x, -pixbuf_y);
-		cairo_pattern_set_matrix (pattern, &matrix);
+        cairo_matrix_init_translate (&matrix, -pixbuf_x, -pixbuf_y);
+        cairo_pattern_set_matrix (pattern, &matrix);
 
-		cairo_set_source (render->cr, pattern);
-		cairo_pattern_destroy (pattern);
-	}
+        cairo_set_source (render->cr, pattern);
+        cairo_pattern_destroy (pattern);
+    }
 #endif
 
     cairo_paint (render->cr);
@@ -768,7 +769,7 @@ rsvg_cairo_generate_mask (cairo_t * cr, RsvgMask * self, RsvgDrawingCtx * ctx, R
     cairo_surface_t *surface;
     cairo_t *mask_cr, *save_cr;
     RsvgCairoRender *render = (RsvgCairoRender *) ctx->render;
-    RsvgState *state = rsvg_state_current (ctx);
+    RsvgState *state = rsvg_current_state (ctx);
     guint8 *pixels;
     guint32 width = render->width, height = render->height;
     guint32 rowstride = width * 4, row, i;
@@ -853,9 +854,9 @@ static void
 rsvg_cairo_push_early_clips (RsvgDrawingCtx * ctx)
 {
     cairo_save (((RsvgCairoRender *) ctx->render)->cr);
-    if (rsvg_state_current (ctx)->clip_path_ref)
-        if (((RsvgClipPath *) rsvg_state_current (ctx)->clip_path_ref)->units == userSpaceOnUse)
-            rsvg_cairo_clip (ctx, rsvg_state_current (ctx)->clip_path_ref, NULL);
+    if (rsvg_current_state (ctx)->clip_path_ref)
+        if (((RsvgClipPath *) rsvg_current_state (ctx)->clip_path_ref)->units == userSpaceOnUse)
+            rsvg_cairo_clip (ctx, rsvg_current_state (ctx)->clip_path_ref, NULL);
 
 }
 
@@ -868,11 +869,11 @@ rsvg_cairo_push_render_stack (RsvgDrawingCtx * ctx)
     cairo_surface_t *surface;
     cairo_t *child_cr;
     RsvgBbox *bbox;
-    RsvgState *state = rsvg_state_current (ctx);
+    RsvgState *state = rsvg_current_state (ctx);
     gboolean lateclip = FALSE;
 
-    if (rsvg_state_current (ctx)->clip_path_ref)
-        if (((RsvgClipPath *) rsvg_state_current (ctx)->clip_path_ref)->units == objectBoundingBox)
+    if (rsvg_current_state (ctx)->clip_path_ref)
+        if (((RsvgClipPath *) rsvg_current_state (ctx)->clip_path_ref)->units == objectBoundingBox)
             lateclip = TRUE;
 
     if (state->opacity == 0xFF
@@ -922,43 +923,6 @@ rsvg_cairo_push_discrete_layer (RsvgDrawingCtx * ctx)
     rsvg_cairo_push_render_stack (ctx);
 }
 
-static GdkPixbuf *
-rsvg_compile_bg (RsvgDrawingCtx * ctx)
-{
-    RsvgCairoRender *render = (RsvgCairoRender *) ctx->render;
-    cairo_t *cr;
-    cairo_surface_t *surface;
-    GList *i;
-    unsigned char *pixels = g_new0 (guint8, render->width * render->height * 4);
-    int rowstride = render->width * 4;
-
-    GdkPixbuf *output = gdk_pixbuf_new_from_data (pixels,
-                                                  GDK_COLORSPACE_RGB, TRUE, 8,
-                                                  render->width, render->height,
-                                                  rowstride,
-                                                  (GdkPixbufDestroyNotify) rsvg_pixmap_destroy,
-                                                  NULL);
-
-    surface = cairo_image_surface_create_for_data (pixels,
-                                                   CAIRO_FORMAT_ARGB32,
-                                                   render->width, render->height, rowstride);
-
-    cr = cairo_create (surface);
-    cairo_surface_destroy (surface);
-
-    for (i = g_list_last (render->cr_stack); i != NULL; i = g_list_previous (i)) {
-        cairo_t *draw = i->data;
-        gboolean nest = draw != render->initial_cr;
-        cairo_set_source_surface (cr, cairo_get_target (draw),
-                                  nest ? 0 : -render->offset_x,
-                                  nest ? 0 : -render->offset_y);
-        cairo_paint (cr);
-    }
-
-    cairo_destroy (cr);
-    return output;
-}
-
 static void
 rsvg_cairo_pop_render_stack (RsvgDrawingCtx * ctx)
 {
@@ -967,11 +931,11 @@ rsvg_cairo_pop_render_stack (RsvgDrawingCtx * ctx)
     gboolean lateclip = FALSE;
     GdkPixbuf *output = NULL;
     cairo_surface_t *surface = NULL;
-    RsvgState *state = rsvg_state_current (ctx);
+    RsvgState *state = rsvg_current_state (ctx);
     gboolean nest;
 
-    if (rsvg_state_current (ctx)->clip_path_ref)
-        if (((RsvgClipPath *) rsvg_state_current (ctx)->clip_path_ref)->units == objectBoundingBox)
+    if (rsvg_current_state (ctx)->clip_path_ref)
+        if (((RsvgClipPath *) rsvg_current_state (ctx)->clip_path_ref)->units == objectBoundingBox)
             lateclip = TRUE;
 
     if (state->opacity == 0xFF
@@ -981,14 +945,12 @@ rsvg_cairo_pop_render_stack (RsvgDrawingCtx * ctx)
 
     if (state->filter) {
         GdkPixbuf *pixbuf = render->pixbuf_stack->data;
-        GdkPixbuf *bg = rsvg_compile_bg (ctx);
 
         render->pixbuf_stack = g_list_remove (render->pixbuf_stack, pixbuf);
 
 
-        output = rsvg_filter_render (state->filter, pixbuf, bg, ctx, &render->bbox, "2103");
-        g_object_unref (G_OBJECT (pixbuf));
-        g_object_unref (G_OBJECT (bg));
+        output = rsvg_filter_render (state->filter, pixbuf, ctx, &render->bbox, "2103");
+        g_object_unref (pixbuf);
 
         surface = cairo_image_surface_create_for_data (gdk_pixbuf_get_pixels (output),
                                                        CAIRO_FORMAT_ARGB32,
@@ -1008,7 +970,7 @@ rsvg_cairo_pop_render_stack (RsvgDrawingCtx * ctx)
                               nest ? 0 : render->offset_y);
 
     if (lateclip)
-        rsvg_cairo_clip (ctx, rsvg_state_current (ctx)->clip_path_ref, &render->bbox);
+        rsvg_cairo_clip (ctx, rsvg_current_state (ctx)->clip_path_ref, &render->bbox);
 
     _rsvg_cairo_set_operator (render->cr, state->comp_op);
 
@@ -1029,7 +991,7 @@ rsvg_cairo_pop_render_stack (RsvgDrawingCtx * ctx)
     render->bb_stack = g_list_delete_link (render->bb_stack, render->bb_stack);
 
     if (state->filter) {
-        g_object_unref (G_OBJECT (output));
+        g_object_unref (output);
         cairo_surface_destroy (surface);
     }
 }
@@ -1047,7 +1009,7 @@ rsvg_cairo_add_clipping_rect (RsvgDrawingCtx * ctx, double x, double y, double w
     RsvgCairoRender *render = (RsvgCairoRender *) ctx->render;
     cairo_t *cr = render->cr;
 
-    _set_rsvg_affine (render, rsvg_state_current (ctx)->affine);
+    _set_rsvg_affine (render, rsvg_current_state (ctx)->affine);
 
     cairo_rectangle (cr, x, y, w, h);
     cairo_clip (cr);
@@ -1082,8 +1044,8 @@ rsvg_cairo_get_image_of_node (RsvgDrawingCtx * ctx,
     rsvg_node_draw (drawable, ctx, 0);
     rsvg_state_pop (ctx);
 
-	/* no colorspace conversion necessary. this is just a convenient
-	   holder of ARGB data with a width, height, & stride */
+    /* no colorspace conversion necessary. this is just a convenient
+       holder of ARGB data with a width, height, & stride */
     img = gdk_pixbuf_new_from_data (pixels,
                                     GDK_COLORSPACE_RGB,
                                     TRUE,
