@@ -1,4 +1,5 @@
-/* vim: set sw=4 sts=4: -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* vim: set sw=4 sts=4 ts=4 expandtab: */
 /*
    rsvg-shapes.c: Draw SVG shapes
 
@@ -338,6 +339,9 @@ _rsvg_node_rect_draw (RsvgNode * self, RsvgDrawingCtx * ctx, int dominate)
     rx = _rsvg_css_normalize_length (&rect->rx, ctx, 'h');
     ry = _rsvg_css_normalize_length (&rect->ry, ctx, 'v');
 
+    if (w == 0. || h == 0.)
+	return;
+
     if (rect->got_rx)
         rx = rx;
     else
