@@ -217,7 +217,7 @@ rsvg_node_use_draw (RsvgNode * self, RsvgDrawingCtx * ctx, int dominate)
     else if (rsvg_node_is_ancestor (child, self))       /* or, if we're <use>'ing ourself */
         return;
 
-    state = rsvg_state_current (ctx);
+    state = rsvg_current_state (ctx);
     if (strcmp (child->type->str, "symbol")) {
         _rsvg_affine_translate (affine, x, y);
         _rsvg_affine_multiply (state->affine, affine, state->affine);
@@ -279,7 +279,7 @@ rsvg_node_svg_draw (RsvgNode * self, RsvgDrawingCtx * ctx, int dominate)
 
     rsvg_state_reinherit_top (ctx, self->state, dominate);
 
-    state = rsvg_state_current (ctx);
+    state = rsvg_current_state (ctx);
 
     for (i = 0; i < 6; i++)
         affine_old[i] = state->affine[i];
@@ -379,6 +379,19 @@ _rsvg_node_svg_apply_atts (RsvgNodeSvg * self, RsvgHandle * ctx)
     }
 }
 
+static void
+_rsvg_svg_free (RsvgNode * self)
+{
+    RsvgNodeSvg *svg = (RsvgNodeSvg *) self;
+
+    if (svg->atts) {
+        rsvg_property_bag_free (svg->atts);
+        svg->atts = NULL;
+    }
+
+    _rsvg_node_free (self);
+}
+
 RsvgNode *
 rsvg_new_svg (void)
 {
@@ -392,6 +405,7 @@ rsvg_new_svg (void)
     svg->w = _rsvg_css_parse_length ("100%");
     svg->h = _rsvg_css_parse_length ("100%");
     svg->super.draw = rsvg_node_svg_draw;
+    svg->super.free = _rsvg_svg_free;
     svg->super.set_atts = rsvg_node_svg_set_atts;
     return &svg->super;
 }
