@@ -1,4 +1,5 @@
-/* vim: set sw=4 sts=4: -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* vim: set sw=4 sts=4 ts=4 expandtab: */
 /*
  * test-display: 
  *
@@ -30,30 +31,106 @@
 #include <gdk/gdk.h>
 #include <gdk/gdkkeysyms.h>
 
-#ifdef HAVE_BASENAME
-#include <libgen.h>
-#endif
-
-#ifdef ENABLE_XEMBED
-#include <gdk/gdkx.h>
-#endif                          /* ENABLE_XEMBED */
-
 #define DEFAULT_WIDTH  640
 #define DEFAULT_HEIGHT 480
 
 static char *
 _rsvg_basename (const char *file)
 {
-#ifdef HAVE_BASENAME
-    if (file && *file) {
-        char *file_dup = g_strdup (file);
-        return basename (file_dup);
-    }
-#endif
+    if (file && *file)
+        return g_path_get_basename (file);
 
     return NULL;
 }
 
+typedef struct _ViewerCbInfo ViewerCbInfo;
+struct _ViewerCbInfo {
+    GtkWidget *window;
+    GtkWidget *popup_menu;
+    GtkWidget *image;           /* the image widget */
+
+    GdkPixbuf *pixbuf;
+    GByteArray *svg_bytes;
+    GtkAccelGroup *accel_group;
+    char *base_uri;
+    char *id;
+    gdouble x_zoom;
+    gdouble y_zoom;
+};
+
+static gboolean
+get_image_size_from_data (ViewerCbInfo *info,
+                          gint *width,
+                          gint *height,
+                          GError **error)
+{
+    RsvgHandle *handle;
+    RsvgDimensionData dimensions;
+    gboolean ret;
+
+    handle = rsvg_handle_new ();
+
+    if (!handle) {
+        g_set_error (error, rsvg_error_quark (), 0, _("Error creating SVG reader"));
+        return FALSE;
+    }
+
+    rsvg_handle_set_base_uri (handle, info->base_uri);
+
+    if (!rsvg_handle_write (handle, info->svg_bytes->data, info->svg_bytes->len, error)) {
+        g_object_unref (handle);
+        return FALSE;
+    }
+
+    if (!rsvg_handle_close (handle, error)) {
+        g_object_unref (handle);
+        return FALSE;
+    }
+
+    ret = rsvg_handle_get_dimensions_sub (handle, &dimensions, info->id);
+    g_object_unref (handle);
+
+    if (width)
+        *width = dimensions.width;
+    if (height)
+        *height = dimensions.height;
+
+    return TRUE;
+}
+
+static gboolean
+calculate_zoom_ratio (ViewerCbInfo *info,
+                      struct RsvgSizeCallbackData *size_data,
+                      GError **error)
+{
+    GdkScreen *screen;
+    gint image_width, image_height;
+    gint screen_width, screen_height;
+    gdouble x_zoom = 1.0, y_zoom = 1.0, zoom;
+
+    if (!get_image_size_from_data (info, &image_width, &image_height, error))
+        return FALSE;
+
+    screen = gdk_screen_get_default ();
+    screen_width = gdk_screen_get_width (screen);
+    screen_height = gdk_screen_get_height (screen);
+
+    if (image_width > screen_width)
+        x_zoom = (gdouble) screen_width / image_width * 0.8;
+
+    if (image_height > screen_height)
+        y_zoom = (gdouble) screen_height / image_height * 0.8;
+
+    zoom = MAX (x_zoom, y_zoom);
+
+    info->x_zoom = zoom;
+    info->y_zoom = zoom;
+    size_data->x_zoom = zoom;
+    size_data->y_zoom = zoom;
+
+    return TRUE;
+}
+
 static GdkPixbuf *
 pixbuf_from_data_with_size_data (const guchar * buff,
                                  size_t len,
@@ -76,43 +153,64 @@ pixbuf_from_data_with_size_data (const guchar * buff,
     rsvg_handle_set_base_uri (handle, base_uri);
 
     if (!rsvg_handle_write (handle, buff, len, error)) {
-        g_object_unref (G_OBJECT (handle));
+        g_object_unref (handle);
         return NULL;
     }
 
     if (!rsvg_handle_close (handle, error)) {
-        g_object_unref (G_OBJECT (handle));
+        g_object_unref (handle);
         return NULL;
     }
 
     retval = rsvg_handle_get_pixbuf_sub (handle, id);
-    g_object_unref (G_OBJECT (handle));
+    g_object_unref (handle);
 
     return retval;
 }
 
-typedef struct _ViewerCbInfo ViewerCbInfo;
-struct _ViewerCbInfo {
-    GtkWidget *window;
-    GtkWidget *popup_menu;
-    GtkWidget *image;           /* the image widget */
+static void
+set_window_title (ViewerCbInfo * info)
+{
+    char *title;
+    gchar *zoom_string;
 
-    GdkPixbuf *pixbuf;
-    GByteArray *svg_bytes;
-    GtkAccelGroup *accel_group;
-    char *base_uri;
-    char *id;
-};
+    if (info->x_zoom != info->y_zoom) {
+        zoom_string = g_strdup_printf ("%4d%% : %4d%%",
+                                       (gint) (info->x_zoom * 100),
+                                       (gint) (info->y_zoom * 100));
+    } else {
+        zoom_string = g_strdup_printf ("%4d%%",
+                                       (gint) (info->x_zoom * 100));
+    }
+
+    if (info->id) {
+        title = g_strdup_printf ("%s#%s (%s) — %s",
+                                 info->base_uri, info->id,
+                                 zoom_string,
+                                 _("SVG Viewer"));
+    } else {
+        title = g_strdup_printf ("%s (%s) — %s",
+                                 info->base_uri,
+                                 zoom_string,
+                                 _("SVG Viewer"));
+    }
+    gtk_window_set_title (GTK_WINDOW (info->window), title);
+    g_free (title);
+    g_free (zoom_string);
+}
 
 static void
-zoom_image (ViewerCbInfo * info, gint width, gint height)
+zoom_image (ViewerCbInfo * info, gdouble factor)
 {
     struct RsvgSizeCallbackData size_data;
     GdkPixbuf *save_pixbuf = info->pixbuf;
 
+    info->x_zoom *= factor;
+    info->y_zoom *= factor;
+
     size_data.type = RSVG_SIZE_WH;
-    size_data.width = width;
-    size_data.height = height;
+    size_data.width = gdk_pixbuf_get_width (info->pixbuf) * factor;
+    size_data.height = gdk_pixbuf_get_height (info->pixbuf) * factor;
     size_data.keep_aspect_ratio = FALSE;
 
     info->pixbuf =
@@ -120,8 +218,10 @@ zoom_image (ViewerCbInfo * info, gint width, gint height)
                                          &size_data, info->base_uri, info->id, NULL);
     gtk_image_set_from_pixbuf (GTK_IMAGE (info->image), info->pixbuf);
 
+    set_window_title (info);
+
     if (save_pixbuf)
-        g_object_unref (G_OBJECT (save_pixbuf));
+        g_object_unref (save_pixbuf);
 }
 
 static void
@@ -129,8 +229,7 @@ zoom_in (GObject * ignored, ViewerCbInfo * info)
 {
     if (!info->pixbuf)
         return;
-    zoom_image (info, gdk_pixbuf_get_width (info->pixbuf) * 1.25,
-                gdk_pixbuf_get_height (info->pixbuf) * 1.25);
+    zoom_image (info, 1.25);
 }
 
 static void
@@ -138,8 +237,7 @@ zoom_out (GObject * ignored, ViewerCbInfo * info)
 {
     if (!info->pixbuf)
         return;
-    zoom_image (info, gdk_pixbuf_get_width (info->pixbuf) / 1.25,
-                gdk_pixbuf_get_height (info->pixbuf) / 1.25);
+    zoom_image (info, 1. / 1.25);
 }
 
 static void
@@ -165,14 +263,14 @@ rsvg_window_set_default_icon (GtkWindow * window, GdkPixbuf * src)
 
         icon = gdk_pixbuf_scale_simple (src, width, height, GDK_INTERP_BILINEAR);
     } else {
-        icon = g_object_ref (G_OBJECT (src));
+        icon = g_object_ref (src);
     }
 
     list = g_list_prepend (NULL, icon);
     gtk_window_set_icon_list (window, list);
     g_list_free (list);
 
-    g_object_unref (G_OBJECT (icon));
+    g_object_unref (icon);
 }
 
 #if GTK_CHECK_VERSION(2,10,0)
@@ -182,7 +280,7 @@ begin_print (GtkPrintOperation *operation,
 			 GtkPrintContext   *context,
 			 gpointer           user_data)
 {
-	gtk_print_operation_set_n_pages(operation, 1);
+	gtk_print_operation_set_n_pages (operation, 1);
 }
 
 static void
@@ -201,16 +299,16 @@ draw_page (GtkPrintOperation *operation,
 	page_height = gtk_print_context_get_height (context);
 
 	{
-		RsvgHandle *handle;
-		RsvgDimensionData svg_dimensions;
-		struct RsvgSizeCallbackData size_data;
+        RsvgHandle *handle;
+        RsvgDimensionData svg_dimensions;
+        struct RsvgSizeCallbackData size_data;
 
-		/* should not fail */
-		handle = rsvg_handle_new_from_data(info->svg_bytes->data, info->svg_bytes->len, NULL);
-		rsvg_handle_set_base_uri (handle, info->base_uri);
-		rsvg_handle_set_dpi_x_y (handle, gtk_print_context_get_dpi_x(context), 
-								 gtk_print_context_get_dpi_y(context));
-		rsvg_handle_get_dimensions(handle, &svg_dimensions);
+        /* should not fail */
+        handle = rsvg_handle_new_from_data(info->svg_bytes->data, info->svg_bytes->len, NULL);
+        rsvg_handle_set_base_uri (handle, info->base_uri);
+        rsvg_handle_set_dpi_x_y (handle, gtk_print_context_get_dpi_x(context), 
+                                 gtk_print_context_get_dpi_y(context));
+        rsvg_handle_get_dimensions(handle, &svg_dimensions);
 
         if (svg_dimensions.width > page_width || svg_dimensions.height > page_height) {
             /* scale down the image to the page's size, while preserving the aspect ratio */
@@ -224,15 +322,15 @@ draw_page (GtkPrintOperation *operation,
             }
         }
 
-		size_data.type = RSVG_SIZE_WH;
-		size_data.width = svg_dimensions.width;
-		size_data.height = svg_dimensions.height;
-		size_data.keep_aspect_ratio = FALSE;
-		rsvg_handle_set_size_callback (handle, _rsvg_size_callback, &size_data, NULL);
+        size_data.type = RSVG_SIZE_WH;
+        size_data.width = svg_dimensions.width;
+        size_data.height = svg_dimensions.height;
+        size_data.keep_aspect_ratio = FALSE;
+        rsvg_handle_set_size_callback (handle, _rsvg_size_callback, &size_data, NULL);
 
-		rsvg_handle_render_cairo(handle, cr);
+        rsvg_handle_render_cairo(handle, cr);
 
-		g_object_unref (handle);
+        g_object_unref (handle);
 	}
 }
 
@@ -529,11 +627,11 @@ populate_window (GtkWidget * win, ViewerCbInfo * info, int xid, gint win_width,
 
         toolitem = gtk_tool_button_new_from_stock (GTK_STOCK_ZOOM_IN);
         gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolitem, 0);
-        g_signal_connect (G_OBJECT (toolitem), "clicked", G_CALLBACK (zoom_in), info);
+        g_signal_connect (toolitem, "clicked", G_CALLBACK (zoom_in), info);
 
         toolitem = gtk_tool_button_new_from_stock (GTK_STOCK_ZOOM_OUT);
         gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolitem, 1);
-        g_signal_connect (G_OBJECT (toolitem), "clicked", G_CALLBACK (zoom_out), info);
+        g_signal_connect (toolitem, "clicked", G_CALLBACK (zoom_out), info);
 
 		gtk_widget_size_request(toolbar, &requisition);
 
@@ -569,43 +667,18 @@ view_pixbuf (ViewerCbInfo * info, int xid, const char *color)
 
     /* create toplevel window and set its title */
 
-#ifdef ENABLE_XEMBED
-    if (xid > 0) {
-        GdkWindow *gdk_parent;
+    win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
-        win = gtk_plug_new (0);
-
-        gdk_parent = gdk_window_foreign_new (xid);
-        gdk_window_get_geometry (gdk_parent, NULL, NULL, &win_width, &win_height, NULL);
-
-        /* so that button and key presses get registered */
-        gtk_widget_add_events (win, GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
-    } else
-#endif
-    {
-        char *title;
-
-        win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-
-        win_width = DEFAULT_WIDTH;
-        win_height = DEFAULT_HEIGHT;
-
-        if (info->id) {
-            title = g_strdup_printf ("%s#%s — %s", info->base_uri, info->id, _("SVG Viewer"));
-        } else {
-            title = g_strdup_printf ("%s — %s", info->base_uri,  _("SVG Viewer"));
-        }
-        gtk_window_set_title (GTK_WINDOW (win), title);
-        g_free (title);
-    }
+    win_width = DEFAULT_WIDTH;
+    win_height = DEFAULT_HEIGHT;
 
     populate_window (win, info, xid, win_width, win_height);
 
     rsvg_window_set_default_icon (GTK_WINDOW (win), info->pixbuf);
 
     /* exit when 'X' is clicked */
-    g_signal_connect (G_OBJECT (win), "destroy", G_CALLBACK (quit_cb), NULL);
-    g_signal_connect (G_OBJECT (win), "delete_event", G_CALLBACK (quit_cb), NULL);
+    g_signal_connect (win, "destroy", G_CALLBACK (quit_cb), NULL);
+    g_signal_connect (win, "delete_event", G_CALLBACK (quit_cb), NULL);
 
     if (color && strcmp (color, "none") != 0) {
         if (gdk_color_parse (color, &bg_color)) {
@@ -625,17 +698,11 @@ view_pixbuf (ViewerCbInfo * info, int xid, const char *color)
     info->window = win;
     gtk_window_add_accel_group (GTK_WINDOW (win), info->accel_group);
 
-    g_signal_connect (G_OBJECT (win), "button-press-event", G_CALLBACK (button_press_event), info);
+    g_signal_connect (win, "button-press-event", G_CALLBACK (button_press_event), info);
 
     gtk_widget_show_all (win);
 
-#ifdef ENABLE_XEMBED
-    if (xid > 0) {
-        XReparentWindow (GDK_WINDOW_XDISPLAY (gtk_widget_get_window(win)),
-                         GDK_WINDOW_XID (gtk_widget_get_window(win)), xid, 0, 0);
-        XMapWindow (GDK_WINDOW_XDISPLAY (gtk_widget_get_window(win)), GDK_WINDOW_XID (gtk_widget_get_window(win)));
-    }
-#endif
+    set_window_title (info);
 }
 
 int
@@ -665,9 +732,6 @@ main (int argc, char **argv)
     gint n_args = 0;
 
     GOptionEntry options_table[] = {
-#ifdef ENABLE_XEMBED
-        {"xid", 'i', 0, G_OPTION_ARG_INT, &xid, N_("XWindow ID [for X11 embedding]"), N_("<int>")},
-#endif
         {"stdin", 's', 0, G_OPTION_ARG_NONE, &from_stdin, N_("Read from stdin instead of a file"),
          NULL},
         {"dpi-x", 'd', 0, G_OPTION_ARG_DOUBLE, &dpi_x, N_("Set the # of Pixels Per Inch"),
@@ -694,7 +758,7 @@ main (int argc, char **argv)
     };
 
 	/* Set the locale so that UTF-8 filenames work */
-	setlocale(LC_ALL, "");
+    setlocale(LC_ALL, "");
 
     g_thread_init (NULL);
 
@@ -793,6 +857,19 @@ main (int argc, char **argv)
 
     info.base_uri = base_uri;
     info.id = id;
+    info.x_zoom = x_zoom;
+    info.y_zoom = y_zoom;
+
+    if (size_data.type == RSVG_SIZE_ZOOM &&
+        x_zoom == 1.0 && y_zoom == 1.0) {
+        if (!calculate_zoom_ratio (&info, &size_data, &err)) {
+            if (err) {
+                g_print (": %s\n", err->message);
+                g_error_free (err);
+            }
+            return 1;
+        }
+    }
 
     info.pixbuf = 
         pixbuf_from_data_with_size_data (info.svg_bytes->data, info.svg_bytes->len, &size_data,
@@ -818,7 +895,7 @@ main (int argc, char **argv)
     /* run the gtk+ main loop */
     gtk_main ();
 
-    g_object_unref (G_OBJECT (info.pixbuf));
+    g_object_unref (info.pixbuf);
     g_byte_array_free (info.svg_bytes, TRUE);
     rsvg_term ();
 
